@@ -2,7 +2,7 @@ from numpy import nan as _nan
 
 from . import _parse_market_state, _TypedDict, _MarketState, _csv2df, \
     _fa_norm_text, _StringIO, _get_content, _BytesIO, _DF, _DataFrame, \
-    _to_numeric
+    _to_numeric, _read_html, _findall, _jstrptime
 
 
 _PRICE_INDEX_COLS = ['ins_code', 'isin', 'l18', 'l30']
@@ -25,14 +25,14 @@ _PRICE_DTYPES = {
     'eps': 'float64',
     'bvol': 'uint64',
     'visitcount': 'uint64',
-    # 0-7 /dev/docs/Instrument_service.html
+    # 0-7 /dev/docs/Instrument.html
     'flow': 'uint8',
     # 1-98 /dev/docs/cs_table.html
     'cs': 'uint8',
     'tmax': 'float64',
     'tmin': 'float64',
     'z': 'uint64',
-    # 67-701 /dev/docs/Instrument_service.html
+    # 67-701 /dev/docs/Instrument.html
     'yval': 'uint16',
 }
 _PRICE_COLUMNS = _PRICE_DTYPES.keys()
@@ -57,11 +57,9 @@ def market_watch_init(
         http://tsetmc.com/Loader.aspx?ParTree=15131F
     For the meaning of column names in the returned DataFrame see:
         https://cdn.tsetmc.com/Site.aspx?ParTree=151713
-        For `flow` and `yval` codes see:
-            http://cdn.tsetmc.com/Site.aspx?ParTree=1114111118&LnkIdn=83
-        For `heven` see:
-            http://cdn.tsetmc.com/Site.aspx?ParTree=111411111S&LnkIdn=129
-            (it's the time of last transaction in HHMMSS format)
+        For `flow` and `yval` codes see: /dev/docs/Instrument.html
+        For `heven` see: /dev/docs/IndexB1LastDayOneInst.html
+            (it's the time of the last transaction in HHMMSS format)
     """
     text = _fa_norm_text('http://tsetmc.com/tsev2/data/MarketWatchInit.aspx?h=0&r=0')
     _, market_state_str, states, price_rows, _ = text.split('@')
@@ -205,3 +203,29 @@ def key_stats() -> _DataFrame:
     df = df.pivot('ins_code', 'n', 'value')
     df.columns = [f'is{c}' for c in df.columns]
     return df
+
+
+def ombud_messages(
+    top: int | str, flow: int | str = 0,
+):
+    text = _fa_norm_text(
+        'http://www.tsetmc.com/Loader.aspx?Partree=151313'
+        f'&Flow={flow}&top={top}')
+    headers = _findall(r'<th>(.+?)</th>', text)
+    dates = _findall(r"<th class='ltr'>(.+?)</th>", text)
+    descriptions = _findall(r'<td colspan="2">(.+?)<hr /></td>', text)
+    df = _DF({'header': headers, 'date': dates, 'description': descriptions})
+    # _jdatetime.strptime does not support %y directive
+    # https://github.com/slashmili/python-jalali/issues/100
+    df['date'] = ('14' + df['date']).apply(_jstrptime, format='%Y/%m/%d %H:%M')
+    return df
+
+
+def status_changes(top: int | str) -> _DataFrame:
+    text = _fa_norm_text(
+        f'http://redirectcdn.tsetmc.com/Loader.aspx?Partree=15131L&top={top}')
+    df = _read_html(text)[0]
+    df['date'] = (df['تاریخ'] + ' ' + df['زمان']).apply(
+        _jstrptime, format='%Y/%m/%d %H:%M')
+    df.drop(columns=['تاریخ', 'زمان'], inplace=True)
+    return df
